///////////////////////////////////////////////////////////////////
//
// Project RENOIR
// Release Notes Instant Reporter
//
// Reference application presented in
// Clean Architecture with .NET (MS Press) 2024
// Author: Dino Esposito
// 
//

using System.ComponentModel.DataAnnotations;

namespace Youbiquitous.Renoir.DomainModel.Documents.Core;

/// <summary>
/// CORE-DOCUMENT entity (properties)
/// </summary>
public partial class CoreDocument<TDocumentItem> : BaseEntity 
    where TDocumentItem : CoreDocumentItem, new()
{
    /// <summary>
    /// Ctor, mostly needed for EF and to save us an entire layer of DTOs
    /// </summary>
    public CoreDocument()
    {
       // Category = DocumentCategory.ReleaseNote;
        Items = new List<TDocumentItem>();
    }
    public CoreDocument(long productId, string version) 
    {
        ProductId = productId;
        Version = version;
        Items = new List<TDocumentItem>();
    }

    /// <summary>
    /// Unique ID (autogenerated)
    /// </summary>
    public long RefId { get; set; }

    /// <summary>
    /// Product ID
    /// </summary>
    public long ProductId { get; set; }

    /// <summary>
    /// Product the document refers to
    /// </summary>
    public Product RelatedProduct { get; set; }

    /// <summary>
    /// Version number
    /// </summary>
    [MaxLength(30)]
    public string Version { get; set; }

    /// <summary>
    /// Display release date
    /// </summary>
    public DateTime ReleaseDate { get; set; }

    /// <summary>
    /// Additional/optional comment on the document
    /// </summary>
    [MaxLength(200)]
    public string Notes { get; set; }

    /// <summary>
    /// List of child items
    /// </summary>
    public List<TDocumentItem> Items { get; set; }
}
